summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/pipeline_d.h
diff options
context:
space:
mode:
authorDavid Storch <david.storch@10gen.com>2014-07-15 17:30:02 -0400
committerDavid Storch <david.storch@10gen.com>2014-07-22 09:24:11 -0400
commit7ffac7f351b80f84589349e44693a94d5cc5e14c (patch)
tree3707298920eabe877af03963f3f61f74c5a61fc5 /src/mongo/db/pipeline/pipeline_d.h
parentfb270d89cbcfdb98c3cee3e631c76ca035c7b4f0 (diff)
downloadmongo-7ffac7f351b80f84589349e44693a94d5cc5e14c.tar.gz
SERVER-14407 replace Runner with PlanExecutor
Diffstat (limited to 'src/mongo/db/pipeline/pipeline_d.h')
-rw-r--r--src/mongo/db/pipeline/pipeline_d.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/pipeline/pipeline_d.h b/src/mongo/db/pipeline/pipeline_d.h
index b9d85a69dbb..1147755f5b6 100644
--- a/src/mongo/db/pipeline/pipeline_d.h
+++ b/src/mongo/db/pipeline/pipeline_d.h
@@ -36,7 +36,7 @@ namespace mongo {
struct ExpressionContext;
class OperationContext;
class Pipeline;
- class Runner;
+ class PlanExecutor;
/*
PipelineD is an extension of the Pipeline class, but with additional
@@ -65,13 +65,13 @@ namespace mongo {
*
* Must have a ReadContext before entering.
*
* If the returned Runner is non-null, you are responsible for ensuring
* it receives appropriate invalidate and kill messages.
*
* @param pPipeline the logical "this" for this operation
* @param pExpCtx the expression context for this pipeline
*/
- static boost::shared_ptr<Runner> prepareCursorSource(
+ static boost::shared_ptr<PlanExecutor> prepareCursorSource(
OperationContext* txn,
Collection* collection,
const intrusive_ptr<Pipeline> &pPipeline,
@@ -65,13 +65,13 @@ namespace mongo {
* Must have a ReadContext before entering.
*
- * If the returned Runner is non-null, you are responsible for ensuring
+ * If the returned PlanExecutor is non-null, you are responsible for ensuring
* it receives appropriate invalidate and kill messages.
*